==> alloydb-jdbc-connector-0.2.0-sources.jar: com/google/cloud/alloydb/DefaultConnectionInfoRepositoryFactory.java <==
/*
 * Copyright 2023 Google LLC
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package com.google.cloud.alloydb;

import com.google.cloud.alloydb.v1.AlloyDBAdminClient;
import com.google.common.util.concurrent.ListeningScheduledExecutorService;
import java.io.IOException;

/** Factory for creating a SQLAdmin client that interacts with the real AlloyDB Admin API. */
class DefaultConnectionInfoRepositoryFactory implements ConnectionInfoRepositoryFactory {
  private final ListeningScheduledExecutorService executor;

  DefaultConnectionInfoRepositoryFactory(ListeningScheduledExecutorService executor) {
    this.executor = executor;
  }

  @Override
  public DefaultConnectionInfoRepository create(
      CredentialFactory credentialFactory, ConnectorConfig config) {

    AlloyDBAdminClient alloyDBAdminClient;
    try {
      alloyDBAdminClient =
          AlloyDBAdminClientFactory.create(
              credentialFactory.create(), config.getAdminServiceEndpoint());
      return new DefaultConnectionInfoRepository(executor, alloyDBAdminClient);
    } catch (IOException e) {
      throw new RuntimeException(e);
    }
  }
}

==> alloydb-jdbc-connector-1.1.1-sources.jar: com/google/cloud/alloydb/DefaultConnectionInfoRepositoryFactory.java <==
/*
 * Copyright 2023 Google LLC
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package com.google.cloud.alloydb;

import com.google.cloud.alloydb.v1alpha.AlloyDBAdminClient;
import com.google.common.util.concurrent.ListeningScheduledExecutorService;
import java.io.IOException;

/** Factory for creating a AlloyDBAdminClient that interacts with the real AlloyDB Admin API. */
class DefaultConnectionInfoRepositoryFactory implements ConnectionInfoRepositoryFactory {
  private final ListeningScheduledExecutorService executor;
  private final String userAgents;

  DefaultConnectionInfoRepositoryFactory(
      ListeningScheduledExecutorService executor, String userAgents) {
    this.executor = executor;
    this.userAgents = userAgents;
  }

  @Override
  public DefaultConnectionInfoRepository create(
      CredentialFactory credentialFactory, ConnectorConfig config) {

    AlloyDBAdminClient alloyDBAdminClient;
    try {
      alloyDBAdminClient =
          AlloyDBAdminClientFactory.create(credentialFactory.create(), config, userAgents);
      return new DefaultConnectionInfoRepository(executor, alloyDBAdminClient);
    } catch (IOException e) {
      throw new RuntimeException(e);
    }
  }
}
